@@ -14,17 +14,13 @@ LOGGER = logging.getLogger(__name__)
 def simpledf() -> pd.DataFrame:
     df = pd.DataFrame(np.random.rand(1000, 3), columns=["a", "b", "c"])
 
-    df = pd.concat(
-        [df, pd.Series(np.random.choice(["a", "b", "c"], 1000, replace=True))], axis=1
-    )
+    df = pd.concat([df, pd.Series(np.random.choice(["a", "b", "c"], 1000, replace=True))], axis=1)
     df = pd.concat([df, pd.Series([["foo"] * 1000])], axis=1)
     df = pd.concat(
         [
             df,
             pd.Series(
-                np.random.choice(
-                    ["2020/03/29", "2020/01/10", "2019/11/21"], 1000, replace=True
-                )
+                np.random.choice(["2020/03/29", "2020/01/10", "2019/11/21"], 1000, replace=True)
             ),
         ],
         axis=1,
@@ -41,4 +37,10 @@ def simpledf() -> pd.DataFrame:
 
 
 def test_report(simpledf: pd.DataFrame) -> None:
+    from sys import platform
+
+    if platform == "darwin":
+        import matplotlib
+
+        matplotlib.use("PS")
     create_report(simpledf, mode="basic")
